Backup your Pootle system — Pootle 2.9.0b2 documentation

# Backup your Pootle system

In particular you should backup:

- All your translation files (your whole `POOTLE_TRANSLATION_DIRECTORY`). Use the `sync_stores` command to synchronize all your translation files to disk before making any backup.
- Your settings, to avoid losing any settings customizations.
- Your complete database using the appropriate dump command for your database system. For example mysqldump for MySQL, or pg_dump for PostgreSQL.
- Any code, templates or styling customization that you have done to your installation.